!Control file for program BLPadFlt
!
! Note on use of "!" to denote a comment line.  This is only used
! for lines in the group of input lines containing processing
! parameters.  Once "pp:" is encountered, the program assumes that
! all following lines until the next "pp:" or "stop" contain
! the names of files to be processed (note that this is consistent
! with file name restrictions:  starting a file name with "!" is legal).
!
! Revision of program involving a change in the control file on this date:
   02/22/18
!Summary file name:
 blpadflt.sum
!
! NOTE: Those parameters most likely to stay fixed are immediately below,
! before the list of files.  Those likely to change for various groups
! of files are set below the "pp:" line.
!
!PARAMETERS FOR OBTAINING THE MEAN:
!
! mean info (contained after "pp:" line below):
! type of mean (0=no correction, 1=standard average; -1=specify mean)
! t4mean_strt, t4mean_stop, mean (use if type = -1)
! NOTE: need entries even if the parameter is not used (because read
! info use list-directed [unformatted] input) 
!
!PARAMETER FOR DETRENDING AFTER MEAN REMOVAL STEP:
!
! 0 = NO; 1 = YES  (the detrending removes a straight line fit to the first
!                   and last points)
!
!PARAMETERS FOR BASELINE ADJUSTMENT:
!
! Info is after "pp:" line below; here are the meanings:
! -Option (0=spcfy T1 & T2; 1=Iwan 1; 2=Iwan 2; 3=t1,t2 from velfit; 10= no bl)
!   (option 4: remove pulse between T1 and T2, whose area equals the mean of 
!    the velocity from t2b to t2e)
! -Fit d or v (0, 1), norder (1:line;2:quad.;3:cubic, etc-- 11 max), prcntfrtpr
! -Array indicating which coefficients are fixed at 0 (0) or are free (1);
!  there must be norder+1 values
! -Torigin, T1b, T1e, T2b, T2e: The equation fitted to the velocity or 
!  displacement is relative to an origin at t = Torigin.  For example, 
!  a straightline fit to velocity will have the equation 
!  v = c(1) + c(2)*(t-torigin).  The Torigin option was included to allow for 
!  a baseline correction starting at t1=t2=torigin,
!  in particular when the polynomial is constrained to be 0.0 at t=torigin 
!  (this is specified by setting the first element in the array of coefficients
!  in the preceeding line to 0.0). The coefficients of the fitted polynomial 
!  are chosen so as to minimize the sum of the squared residuals between 
!  T1b--T1e and T2b--T2e.  The first range (T1b--T1e) was included following 
!  the suggestion of V. Graizer to allow a portion near the beginning of the 
!  record to have some influence on the fitted function; in practice, this 
!  option is rarely used, and the usual specification is T1b = T1e = 0.0.
!
!PARAMETERS FOR ZERO PADDING:
!
! Add pads if apply acausal filter (Y/N)?  This should almost always be
! set to "Y".   Even if it is set to "N", note that the subroutine that
! does the filtering adds pads (but it does not go to the first zero crossing 
! and it does not save the padded time series)
 Y
! Factor by which the number of zeros is increased beyond that determined by
! the standard (BAP) equation (using a number greater than 1.0 may be necessary if the
! full effect of the filter at very low frequencies, as seen in plots of FAS,
! is to be obtained; see dependence_of_fourier_amplitude_spectra_at_low_frequencies_on_zero_pads.pdf
! in http://www.daveboore.com/daves_notes.html for an example and discussion).
 1.0
! Replace discarded portions of original data with zeros (Y/N)?  By doing this,
! two horizontal components with the same number of time points before
! padding (the usual case) will have the same number after padding and can
! be rotated.
 Y
!
! Go to first zero crossing?
 Y
! If go to first zero crossing = Y, use first point rather than the zero crossing 
! if smaller than first zero crossing (this parameter is ignored if specify "N" above,
! in which case the first point is always used)?
 Y
! Go to last zero crossing?
 Y
! If go to last zero crossing = Y, use last point rather than the zero crossing 
! if smaller than last zero crossing (this parameter is ignored if specify "N" above,
! in which case the last point is always used)?
 Y
!
! IMPORTANT NOTE: Care must be taken if the zero pads start at a point 
! determined by going inward to the first or last zero crossings
! ("Go to first/last zero crossing = Y"). Look at the headers of the smc files
! to see how many data points were skipped.
! Sometimes the beginning or end of the unfiltered time series has a drift, in
! which case too many points will be skipped before the first zero crossing is
! reached.
!
!    11/03/06 - If zcross_l or zcross_t = F and use_first or use_last = T, 
!               pad with values equal to the last points.  Allow this option
!               to deal with cases such as filtering a displacement
!               time series with a low-frequency drift, which will have
!               a step offset if pad with zeros at the end.  Be careful in
!               in using this option for the first points, however (in
!               a future version I may eliminate the option for the beginning,
!               as generally the leading pad should be zero).  The need for
!               this option arose when I tried to filter a displacement
!               obtained by integrating a zeroth-order corrected acceleration.
!               The results were different than filtering the acceleration
!               before integration.
!               IF WANT TO PAD WITH ZEROS, STARTING AT 
!               BEGINNING AND END OF DATA, SET ZCROSS_L, ZCROSS_T = F AND
!               USE_FIRST, USE_LAST = F (This is potentially confusing, and
!               I may remove the option of padding with the first and last
!               values in a later version of the program)
!
! Remove mean before determining segment to be padded?
! If Yes, the mean will be determined from the whole record.  If this
! is not desireable, remove the mean outside of this program
 N
! Remove mean after determining segment to be padded (the segment
! will probably be different than the segment originally used to determine the
! mean, and therefore the mean will no longer be 0.0. But then after removing
! this mean, the segment to be padded will not be at 0.0 values, but I 
! hope this is a small problem.  I probably should iterate):
 N
! Save padded time series?  (".pad" will be appended to file name)
 Y
!
!PARAMETERS FOR FILTERING:
!
! flc, nslope_lc, fhc (0 = no filter), nslope_hc, icaus(1=causal)
!  (nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal; this is
!   enforced in the program)
! note that nslope is the asymptotic power of frequency, so that the filter
! goes as f^{nslope} for a low-cut filter and f^{-nslope} for a 
! high-cut filter. In previous versions I used "nroll" as the parameter 
! controlling the asymptotic behavior of the filter, the reason being that it 
! is the parameter used by the filter routines in BAP.   This was always
! confusing, so I switched to nslope on 27 Oct. 2005, with a translation to
! nroll in blpadflt (nroll = 0.5*nslope for causal and 
! nroll = 0.25*nslope for acausal). (Note more confusing terminology:
! nroll = 0.5*npoles for a causal Butterworth filter.) 
! The response of an acausal filter
! is not that of a Butterworth, because time domain filters are used.
! Bazzuro et al. (2004 COSMOS paper) use the terminology npnp, where
! "n" is the number of poles of a standard Butterworth filter.  The "npnp"
! notation is used to indicate that two passes of a Butterworth filter are
! used.   So, for example, "2p2p" means that two passes of a two-pole
! Butterworth filter are used, with an asymptotic dependence as f^4 (for a
! low-cut filter). This notation is used to distinguish this case
! from that in which an acausal filter is simulated in the frequency domain, in
! which case the filter can have a true Butterworth response function. For that 
! case, a "4p" acausal filter constructed in the frequency 
! domain and using the standard Butterworth response would have the same
! asymptotic dependence (f^4).
!
! I added a notch filter on 03/20/10.  The notch filter is invoked if
! (flc = fhc) and flc /= 0.0, and the width parameter "d" of the filter is given by 
! d = real(nslope_lc)*10.0**real(-abs(nslope_hc)).  Adding this new filter did
! not require a change in the input parameters, but I changed the date of the
! control file to make the user aware of a change in the capability of the
! program. Here is a sample specification:
!   25.0 1  25.0 2  0
! which corresponds to a 25 Hz notch filter with filter width of 
! 1*10**(-2)= 0.01, which is the starting trial value recommended by 
! Bill Joyner, who wrote the notch filter subroutine.
!
! On 07/11/17 I allowed for the low-cut and high-cut to be causal or acausal
! separately; previously, both were either causal or acausal.  I made the change
! because causal low-cut filters can affect high frequency response spectra, whereas
! there might be some advantages to using a causal high-cut filter because the filter
! is down by 1/sqrt 2 at the corner frequency rather than 1/2 (thus giving a sharper transition
! between the unfiltered and filtered portions of the spectra).  Previously I need to run blpadflt
! twice to achieve this, the first time with an acausal low-cut filter, and then using
! the resulting padded time series in a second run of blpadflt for a causal high-cut
! filter.  
!
! In the previous version, the filter routine "band" was called if both flc and fhc /= 0.0 and
! flc /= fhc.  The possibility of different types of filters for flc and fhc means that I need to call
! locut and hicut separately, but I want to retain the possibility of a band filter.  For that reason I
! added a Y/N parameter to indicate if a band filter is desired. If Yes, then it will be
! a causal filter only if both icaus_lc and icaus_hc = 1.
!
!ACCURACY OF TIME SERIES OUTPUT 
!Use the higher precision format for the output time series files,
!even if the input file has the standard precision? (Y/N) 
 Y
!
!PARAMETERS FOR RESPONSE SPECTRA:
!
!Periods for response spectra (nperiods log spaced from per_low to per_high):
 200 0.01 90
!Damping values (ndamp, damp(1), damp(2), ..., damp(ndamp)):
 1 0.05 0.20
!Sinc interpolate factor (IF) (this MUST be a power of two; e.g., 2, 4, 8, etc.;
! IF = 1 returns the original data):
! sps_out = interpolate_factor* sps_in
! IF = 8 is high enough, because the sinc interpolation assumes that there
! is no energy beyond the Nyquist data of the original data.  This is 0.5*sps_in.
! If want to resolve an oscillator response with this frequency using at least 10 points
! per period, this means resampling so that sps_in = 10 * 0.5*sps_in = 5 *sps_in.
! Because a power of 2 is needed, IF = 8 is sufficient (see comparisons in Wang et al, PEER 2018/xx)
! Note that the resampling of the filtered time series is used only for computing response spectra;
! the smc output files are at the same sps as the input.  If resampled smc files are desired,
! use the program smc_interpolate_time_series_using_fork.
 8
!Use straightline interpolation if Tosc < 10*dt (even after any sinc interpolation)
 Y
!
!PROCESSING PARAMETERS AND FILES, IN GROUPS
!
pp: new set of parameters
!tskip tlength  
 0.0 400.0
!mean: type (-1=specify,0=none,1=standard), t4mean_strt, t4mean_stop, 
!mean (use if type = -1):
 1  0.0 8.0  -999.
!detrend after mean removal (0=no, 1=yes, in which case a line fit to
!the first and last points is removed; note that the mean need not be removed
!before detrending if type = 0 above.  In addition, caution should be used in
!using this option for "normal" time series; it is intended as a quick
!baseline correction for the infrequent cases in which there is a large
!linear trend in the time series):
 0
!Option (0=spcfy T1 & T2; 1=Iwan 1; 2=Iwan 2; 3=t1,t2 from velfit; 4=pulse; 
!        10= no bl)
 10
!T1,T2 (options 0,4;A1,A2 if <0);A1,A2 (option 1); T1 (option 2; A1 if T1<0.0):
 10.0 20.0 
!Fit d or v (0, 1), norder (1:line;2:quad.;3:cubic, etc-- 11 max), prcntfrtpr:
 1  3  0
!Array showing coefficients fixed at 0 (0) or free (1); must be norder+1 
!values:
 0 0 1 1   ! cubic, with first and second terms constrained to zero
!Torigin, T1b, T1e, T2b, T2e (fit between T1b--T1e and T2b--T2e):
 0.0  0.0 0.0 56.0 200.0
!Filter information (see earlier text for information):
! flc, nslope_lc, icaus_lc, fhc, nslope_hc, icaus_hc
! (flc, fhc = 0 for no filter; icaus = 0 for acausal, 1 for causal)
! (nslope >= 2: nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal)
 0.02 8 0  0.0  4  0
! If this a band filter (Y/N)? (the entry is not used if either flc or fhc = 0 or if
! flc == fhc)
 N
!
!Length of taper at beginning and end of time series, before adding zeros
! (Not used if no filter or a causal filter, but still need this parameter
! (in the input file):
 0.0 0.0
!character string to append to filename to make the output filename:
! if this character string equals "<auto>", the extension will be constructed
! from the filter information (e.g., for a 0.125 Hz acausal low-cut filter 
! with a slope of 8, the extension will be '.alc00.125ns08').
 <auto>
!integrate to velocity and displacement? (y/n):
 y
!Are the units of acceleration in g (Y/N); if N, I assume that the units are
! cm/s/s.  If something else, it is up to the user to scale the output appropriately 
! (the output units are as follows: sd(cm); pv(cm/s); pa(cm/s/s); rv(cm/s); aa(cm/s/s); ag (g)
! where the output columns indicate the type of response spectra, as follows:
! sd=relative displacement
! pv=pseudo relative velocity
! pa=pseudo absolute acceleration (aka PSA)
! rv=relative velocity
! aa=absolute acceleration
! ag=pseudo absolute acceleration, in g.
! (see aa_pa_rv_pv_2.pdf on the Dave's informal notes on a variety of topics page of www.daveboore.com)
 N
!Names of files to be processed with the parameters above:
501053xa.raw.smc
501053za.raw.smc
pp: new set of parameters
!tskip tlength  
 0.0 400.0
!mean: type (-1=specify,0=none,1=standard), t4mean_strt, t4mean_stop, 
!mean (use if type = -1):
 1  0.0 8.0  -999.
!detrend after mean removal (0=no, 1=yes, in which case a line fit to
!the first and last points is removed; note that the mean need not be removed
!before detrending if type = 0 above.  In addition, caution should be used in
!using this option for "normal" time series; it is intended as a quick
!baseline correction for the infrequent cases in which there is a large
!linear trend in the time series):
 0
!Option (0=spcfy T1 & T2; 1=Iwan 1; 2=Iwan 2; 3=t1,t2 from velfit; 4=pulse; 
!        10= no bl)
 10
!T1,T2 (options 0,4;A1,A2 if <0);A1,A2 (option 1); T1 (option 2; A1 if T1<0.0):
 10.0 20.0 
!Fit d or v (0, 1), norder (1:line;2:quad.;3:cubic, etc-- 11 max), prcntfrtpr:
 1  3  0
!Array showing coefficients fixed at 0 (0) or free (1); must be norder+1 
!values:
 0 0 1 1   ! cubic, with first and second terms constrained to zero
!Torigin, T1b, T1e, T2b, T2e (fit between T1b--T1e and T2b--T2e):
 0.0  0.0 0.0 56.0 200.0
!Filter information (see earlier text for information):
! flc, nslope_lc, icaus_lc, fhc, nslope_hc, icaus_hc
! (flc, fhc = 0 for no filter; icaus = 0 for acausal, 1 for causal)
! (nslope >= 2: nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal)
 0.04 8 0 0.0  4  0
! If this a band filter (Y/N)? (the entry is not used if either flc or fhc = 0 or if
! flc == fhc)
 N
!
!Length of taper at beginning and end of time series, before adding zeros
! (Not used if no filter or a causal filter, but still need this parameter
! (in the input file):
 0.0 0.0
!character string to append to filename to make the output filename:
! if this character string equals "<auto>", the extension will be constructed
! from the filter information (e.g., for a 0.125 Hz acausal low-cut filter 
! with a slope of 8, the extension will be '.alc00.125ns08').
 <auto>
!integrate to velocity and displacement? (y/n):
 y
!Are the units of acceleration in g (Y/N); if N, I assume that the units are
! cm/s/s.  If something else, it is up to the user to scale the output appropriately 
! (the output units are as follows: sd(cm); pv(cm/s); pa(cm/s/s); rv(cm/s); aa(cm/s/s); ag (g)
! where the output columns indicate the type of response spectra, as follows:
! sd=relative displacement
! pv=pseudo relative velocity
! pa=pseudo absolute acceleration (aka PSA)
! rv=relative velocity
! aa=absolute acceleration
! ag=pseudo absolute acceleration, in g.
! (see aa_pa_rv_pv_2.pdf on the Dave's informal notes on a variety of topics page of www.daveboore.com)
 N
!Names of files to be processed with the parameters above:
501053xa.raw.smc
501053za.raw.smc
pp: new set of parameters
!tskip tlength  
 0.0 400.0
!mean: type (-1=specify,0=none,1=standard), t4mean_strt, t4mean_stop, 
!mean (use if type = -1):
 1  0.0 8.0  -999.
!detrend after mean removal (0=no, 1=yes, in which case a line fit to
!the first and last points is removed; note that the mean need not be removed
!before detrending if type = 0 above.  In addition, caution should be used in
!using this option for "normal" time series; it is intended as a quick
!baseline correction for the infrequent cases in which there is a large
!linear trend in the time series):
 0
!Option (0=spcfy T1 & T2; 1=Iwan 1; 2=Iwan 2; 3=t1,t2 from velfit; 4=pulse; 
!        10= no bl)
 10
!T1,T2 (options 0,4;A1,A2 if <0);A1,A2 (option 1); T1 (option 2; A1 if T1<0.0):
 10.0 20.0 
!Fit d or v (0, 1), norder (1:line;2:quad.;3:cubic, etc-- 11 max), prcntfrtpr:
 1  3  0
!Array showing coefficients fixed at 0 (0) or free (1); must be norder+1 
!values:
 0 0 1 1   ! cubic, with first and second terms constrained to zero
!Torigin, T1b, T1e, T2b, T2e (fit between T1b--T1e and T2b--T2e):
 0.0  0.0 0.0 56.0 200.0
!Filter information (see earlier text for information):
! flc, nslope_lc, icaus_lc, fhc, nslope_hc, icaus_hc
! (flc, fhc = 0 for no filter; icaus = 0 for acausal, 1 for causal)
! (nslope >= 2: nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal)
 0.02 8 0 0.0  4  0
! If this a band filter (Y/N)? (the entry is not used if either flc or fhc = 0 or if
! flc == fhc)
 N
!
!Length of taper at beginning and end of time series, before adding zeros
! (Not used if no filter or a causal filter, but still need this parameter
! (in the input file):
 0.0 20.0
!character string to append to filename to make the output filename:
! if this character string equals "<auto>", the extension will be constructed
! from the filter information (e.g., for a 0.125 Hz acausal low-cut filter 
! with a slope of 8, the extension will be '.alc00.125ns08').
 <auto>
!integrate to velocity and displacement? (y/n):
 y
!Are the units of acceleration in g (Y/N); if N, I assume that the units are
! cm/s/s.  If something else, it is up to the user to scale the output appropriately 
! (the output units are as follows: sd(cm); pv(cm/s); pa(cm/s/s); rv(cm/s); aa(cm/s/s); ag (g)
! where the output columns indicate the type of response spectra, as follows:
! sd=relative displacement
! pv=pseudo relative velocity
! pa=pseudo absolute acceleration (aka PSA)
! rv=relative velocity
! aa=absolute acceleration
! ag=pseudo absolute acceleration, in g.
! (see aa_pa_rv_pv_2.pdf on the Dave's informal notes on a variety of topics page of www.daveboore.com)
 N
!Names of files to be processed with the parameters above:
501053xa.raw.smc
501053za.raw.smc
pp: new set of parameters
!tskip tlength  
 0.0 400.0
!mean: type (-1=specify,0=none,1=standard), t4mean_strt, t4mean_stop, 
!mean (use if type = -1):
 1  0.0 8.0  -999.
!detrend after mean removal (0=no, 1=yes, in which case a line fit to
!the first and last points is removed; note that the mean need not be removed
!before detrending if type = 0 above.  In addition, caution should be used in
!using this option for "normal" time series; it is intended as a quick
!baseline correction for the infrequent cases in which there is a large
!linear trend in the time series):
 0
!Option (0=spcfy T1 & T2; 1=Iwan 1; 2=Iwan 2; 3=t1,t2 from velfit; 4=pulse; 
!        10= no bl)
 10
!T1,T2 (options 0,4;A1,A2 if <0);A1,A2 (option 1); T1 (option 2; A1 if T1<0.0):
 10.0 20.0 
!Fit d or v (0, 1), norder (1:line;2:quad.;3:cubic, etc-- 11 max), prcntfrtpr:
 1  3  0
!Array showing coefficients fixed at 0 (0) or free (1); must be norder+1 
!values:
 0 0 1 1   ! cubic, with first and second terms constrained to zero
!Torigin, T1b, T1e, T2b, T2e (fit between T1b--T1e and T2b--T2e):
 0.0  0.0 0.0 56.0 200.0
!Filter information (see earlier text for information):
! flc, nslope_lc, icaus_lc, fhc, nslope_hc, icaus_hc
! (flc, fhc = 0 for no filter; icaus = 0 for acausal, 1 for causal)
! (nslope >= 2: nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal)
 0.04 8 0 0.0  4  0
! If this a band filter (Y/N)? (the entry is not used if either flc or fhc = 0 or if
! flc == fhc)
 N
!
!Length of taper at beginning and end of time series, before adding zeros
! (Not used if no filter or a causal filter, but still need this parameter
! (in the input file):
 0.0 20.0
!character string to append to filename to make the output filename:
! if this character string equals "<auto>", the extension will be constructed
! from the filter information (e.g., for a 0.125 Hz acausal low-cut filter 
! with a slope of 8, the extension will be '.alc00.125ns08').
 <auto>
!integrate to velocity and displacement? (y/n):
 y
!Are the units of acceleration in g (Y/N); if N, I assume that the units are
! cm/s/s.  If something else, it is up to the user to scale the output appropriately 
! (the output units are as follows: sd(cm); pv(cm/s); pa(cm/s/s); rv(cm/s); aa(cm/s/s); ag (g)
! where the output columns indicate the type of response spectra, as follows:
! sd=relative displacement
! pv=pseudo relative velocity
! pa=pseudo absolute acceleration (aka PSA)
! rv=relative velocity
! aa=absolute acceleration
! ag=pseudo absolute acceleration, in g.
! (see aa_pa_rv_pv_2.pdf on the Dave's informal notes on a variety of topics page of www.daveboore.com)
 N
!Names of files to be processed with the parameters above:
501053xa.raw.smc
501053za.raw.smc
 stop

   