!Control file for program Filt_Plot_LC
!
! Note on use of "!" to denote a comment line.  This is only used
! for lines in the group of input lines containing processing
! parameters.  Once "pp:" is encountered, the program assumes that
! all following lines until the next "pp:" or "stop" contain
! the names of files to be processed (note that this is consistent
! with file name restrictions:  starting a file name with "!" is legal).
!
! Revision of program involving a change in the control file on this date:
   06/13/09
!Summary file name:
 filt_plot_lc.sum
!
! NOTE: Those parameters most likely to stay fixed are immediately below,
! before the list of files.  Those likely to change for various groups
! of files are set below the "pp:" line.
!
!PARAMETERS FOR OBTAINING THE MEAN:
!
! mean info (contained after "pp:" line below):
! type of mean (0=no correction, 1=standard average; -1=specify mean)
! t4mean_strt, t4mean_stop, mean (use if type = -1)
! NOTE: need entries even if the parameter is not used (because read
! info use list-directed [unformatted] input) 
!
!PARAMETER FOR DETRENDING AFTER MEAN REMOVAL STEP:
!
! 0 = NO; 1 = YES  (the detrending removes a straight line fit to the first and
!                   last points)
!
!PARAMETERS FOR ZERO PADDING:
!
! Add pads if apply acausal filter (Y/N)?  This should almost always be
! set to "Y".   Even if it is set to "N", note that the subroutine that
! does the filtering adds pads (but it does not go to the first zero crossing 
! and it does not save the padded time series)
 Y
! Factor by which the number of zeros is increased beyond that determined by
! the standard (BAP) equation.
 1.0
! Replace discarded portions of original data with zeros (Y/N)?  By doing this,
! two horizontal components with the same number of time points before
! padding (the usual case) will have the same number after padding and can
! be rotated.
 Y
!
! Go to first zero crossing?
 Y
! Use first point if smaller than first zero crossing?
 Y
! Go to last zero crossing?
 Y
! Use last point if smaller than last zero crossing?
 Y
!
! IMPORTANT NOTE: Care must be taken if the zero pads start at a point 
! determined by going inward to the first or last zero crossings
! ("Go to first/last zero crossing = T").    
! Look at the headers of the smc files to see how many data points were 
! skipped. Sometimes the beginning or end of the unfiltered time series 
! has a drift, in which case too many points will be skipped before the 
! first zero crossing is reached.
!
!   11/03/06 - If zcross_l or zcross_t = F and use_first or use_last = T, 
!              pad with values equal to the last points.  Allow this option
!              to deal with cases such as filtering a displacement
!              time series with a low-frequency drift, which will have
!              a step offset if pad with zeros at the end.  Be careful in
!              in using this option for the first points, however (in
!              a future version I may eliminate the option for the beginning,
!              as generally the leading pad should be zero).  The need for
!              this option arose when I tried to filter a displacement
!              obtained by integrating a zeroth-order corrected acceleration.
!              The results were different than filtering the acceleration
!              before integration.
!              IF WANT TO PAD WITH ZEROS, STARTING AT 
!              BEGINNING AND END OF DATA, SET ZCROSS_L, ZCROSS_T = F AND
!              USE_FIRST, USE_LAST = F (This is potentially confusing, and
!              I may remove the option of padding with the first and last
!              values in a later version of the program)
!
! Remove mean before determining segment to be padded?
! If Yes, the mean will be determined from the whole record.  If this
! is not desireable, remove the mean outside of this program
 N
! Remove mean after determining segment to be padded (the segment
! will probably be different than the segment originally used to determine the
! mean, and therefore the mean will no longer be 0.0. But then after removing
! this mean, the segment to be padded will not be at 0.0 values, but 
! I hope this is a small problem.  I probably should iterate):
 N
! Save padded time series?  (".pad" will be appended to file name)
 Y
!
!PARAMETERS FOR FILTERING:
!
! flc, nslope_lc, fhc (0 = no filter), nslope_hc, icaus(1=causal)
!  (nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal; this is
!   enforced in the program)
! note that nslope is the asymptotic power of frequency, so that the filter
! goes as f^{nslope} for a low-cut filter and f^{-nslope} for a
! high-cut filter. In previous versions I used "nroll" as the parameter 
! controlling the asymptotic behavior of the filter, the reason being that 
! it is the parameter used by the filter routines in BAP.   This was always
! confusing, so I switched to nslope on 27 Oct. 2005, with a translation to
! nroll in blpadflt (nroll = 0.5*nslope for causal and 
! nroll = 0.25*nslope for acausal). (Note more confusing terminology:
! nroll = 0.5*npoles for a causal Butterworth filter.) 
! The response of an acausal filter
! is not that of a Butterworth, because time domain filters are used.
! Bazzuro et al. (2004 COSMOS paper) use the terminology npnp, where
! "n" is the number of poles of a standard Butterworth filter.  The "npnp"
! notation is used to indicate that two passes of a Butterworth filter are
! used.   So, for example, "2p2p" means that two passes of a two-pole
! Butterworth filter are used, with an asymptotic dependence as f^4 (for a
! low-cut filter). This notation is used to distinguish this case
! from that in which an acausal filter is simulated in the frequency domain, in
! which case the filter can have a true Butterworth response function. 
! For that case, a "4p" acausal filter constructed in the frequency 
! domain and using the standard Butterworth response would have the same
! asymptotic dependence (f^4).
!
!RESPONSE SPECTRA PARAMETERS
!Periods for response spectra (nperiods log spaced from per_low to per_high):
 200 0.01 90
!Damping value
  0.05  
!PLOT PARAMETERS
!Plot v(1), d(2), or both(3)?
 2
!start time, duration to plot (<=0 to start at 1st pt; >>= 0 to plot all):
0.0 900.0
!peak-to-peak distance (cm) (ntraces*(p2p+0.5)<= 23.5, prog will reset if 
! needed)
 5.0
!PROCESSING PARAMETERS AND FILES, IN GROUPS
!
pp: new set of parameters
!mean: type (-1=specify,0=none,1=standard), t4mean_strt, t4mean_stop, 
!mean (use if type = -1):
 1  0.0 2000.0  -999.
!detrend after mean removal (0=no, 1=yes, in which case a line fit to
!the first and last points is removed; note that the mean need not be removed
!before detrending if type = 0 above):
 0
!flow, fhigh, number of filters (<=20) (frequencies will be evenly spaced in 
! log f)
  0.2, 2.0, 10
!nslope_lc, fhc (0 = no filter), nslope_hc, icaus(1=causal) (nslope >= 2)
!  (nslope >= 2,4,6, etc for causal and 4,8,12, etc for acausal; this is
!   enforced in the program).  These are the same for each flc
 8  0.0  4  0
!Length of taper at beginning and end of time series, before adding zeros
! (Not used if no filter or a causal filter, but still need this parameter
! (in the input file):
 2.0 5.0
!Names of files to be processed with the parameters above:
 HER19401.L.dat.smc
 stop
